#!/usr/bin/perl -w
#

# Plugin directory / home of utils.pm.
use lib "/usr/lib/nagios/plugins";
use utils qw(%ERRORS &print_revision &support &usage);
use Getopt::Long qw(:config no_ignore_case bundling);
use File::Basename;
use Net::DNS;

use strict;

# Path to installed clamd binary.
my $iptable_cmd  = "sudo iptables";
my $warn_val = 1;  # Default -w arg
my $crit_val = 2;  # Default  -c arg
my $help_val = 0;  # Off unless -h arg
my $debug_val = 0;  # Off unless -h arg
my $chaine = "mor-lan";
my $indicateur = "DROP ";


sub show_help() {
    print <<END;

Usage: check_iptables_state [-C <chaine>] [ -S <indicateur>] [-w <warn>] [-c <crit>]  [-h]

-w, --warning=INTEGER
-c, --critical=INTEGER
-I, --Indicateur a rechercher DROP par defaut
-C, --chaine iptable (mor-lan par defaut)
   Chaine dans laquelle recuperer les statistiques
-h, --help
-v, --verbose
END
}

GetOptions (
    "w=i" => \$warn_val, "warning=i" => \$warn_val,
    "c=i" => \$crit_val, "critical=i" => \$crit_val,
    "h" => \$help_val, "help" => \$help_val,
    "v" => \$debug_val, "verbose" => \$debug_val,
    "C=s" => \$chaine, "chaine=s" => \$chaine,
    "I=s" => \$indicateur, "indicateur=s" => \$indicateur
);

if ($help_val != 0) {
    &show_help;
    exit 0;
}

my ($total,$diff,$update_time,$row, @last_values, $last_time,$last_VolIntOut, $last_VolIntIn, $last_VolM2Out, $last_VolM2In, $last_VolKAKOut,$last_VolKAKIn,$last_VolSUSOut,$last_VolSUSIn);
my ($Tindic1,$Tindic2,$Tindic3,$Tindic4,$Tindic5);

#recup volume internet out et in
chomp(my $VolIntIn = `$iptable_cmd -nvL mor-lan -x |grep "ACC-flux_in-lan-proxies " |awk -F' ' '{print \$2}'`);
chomp(my $VolIntOut = `$iptable_cmd -nvL lan-mor -x |grep "ACC-flux_out-lan-proxies " |awk -F' ' '{print \$2}'`);


chomp(my $VolM2In = `$iptable_cmd -nvL mor-lan -x |grep "ACC-flux_in-lan-melanie2 " |awk -F' ' '{print \$2}'`);
chomp(my $VolM2Out = `$iptable_cmd -nvL lan-mor -x |grep "ACC-flux_out-lan-melanie2 " |awk -F' ' '{print \$2}'`);

chomp(my $VolKAKIn = `$iptable_cmd -nvL mor-lan -x |grep "ACC-flux_in-lan-kak " |awk -F' ' '{print \$2}'`);
chomp(my $VolKAKOut = `$iptable_cmd -nvL lan-mor -x |grep "ACC-flux_out-lan-kak " |awk -F' ' '{print \$2}'`);

chomp(my $VolSUSIn = `$iptable_cmd -nvL mor-lan -x |grep "ACC-flux_in-lan-wsus " |awk -F' ' '{print \$2}'`);
chomp(my $VolSUSOut = `$iptable_cmd -nvL lan-mor -x |grep "ACC-flux_out-lan-wsus " |awk -F' ' '{print \$2}'`);

my @Resultat;

if ($VolIntIn eq ""){$VolIntIn=0;}
if ($VolM2In eq ""){$VolM2In=0;}
if ($VolKAKIn eq ""){$VolKAKIn=0;}
if ($VolSUSIn eq ""){$VolSUSIn=0;}
if ($VolIntOut eq ""){$VolIntOut=0;}
if ($VolM2Out eq ""){$VolM2Out=0;}
if ($VolKAKOut eq ""){$VolKAKOut=0;}
if ($VolSUSOut eq ""){$VolSUSOut=0;}

$Resultat[0]=$VolIntIn;
$Resultat[1]=$VolM2In;
$Resultat[2]=$VolKAKIn;
$Resultat[3]=$VolSUSIn;
$Resultat[4]=$VolIntOut;
$Resultat[5]=$VolM2Out;
$Resultat[6]=$VolKAKOut;
$Resultat[7]=$VolSUSOut;
my @perf;
$perf[0]="Internet-In";
$perf[1]="Melanie2-In";
$perf[2]="KAK-In";
$perf[3]="WSUS-In";
$perf[4]="Internet-Out";
$perf[5]="Melanie2-Out";
$perf[6]="KAK-Out";
$perf[7]="WSUS-Out";

if ($debug_val != 0) { print "Volume Internet Out/In :".$VolIntIn."/".$VolIntOut." Volume Melanie2 Out/In : ".$VolM2Out."/".$VolM2In." Volume KAK Out/In : ".$VolKAKOut."/".$VolKAKIn." Volume SUS Out/In : ".$VolSUSOut."/".$VolSUSIn;}

my $flg_created = 0;

if (-e "/tmp/indic_iptable.log") {
    open(FILE,"<"."/tmp/indic_iptable.log");
    while($row = <FILE>){
       @last_values = split(":",$row);
       $last_time = $last_values[0];
       $last_VolIntOut = $last_values[1];
       $last_VolIntIn = $last_values[2];
       $last_VolM2Out = $last_values[3];
       $last_VolM2In = $last_values[4];
       $last_VolKAKOut = $last_values[5];
       $last_VolKAKIn = $last_values[6];
       $last_VolSUSOut = $last_values[7];
       $last_VolSUSIn = $last_values[8];
       $flg_created = 1;
    }
    close(FILE);
} else {
    $flg_created = 0;
}
my @last_Resultat;
$last_Resultat[0]=$last_VolIntIn;
$last_Resultat[1]=$last_VolM2In;
$last_Resultat[2]=$last_VolKAKIn;
$last_Resultat[3]=$last_VolSUSIn;
$last_Resultat[4]=$last_VolIntOut;
$last_Resultat[5]=$last_VolM2Out;
$last_Resultat[6]=$last_VolKAKOut;
$last_Resultat[7]=$last_VolSUSOut;


$update_time = time();
unless (open(FILE,">"."/tmp/indic_iptable.log")){
    print "Check mod for temporary file : /tmp/indic_iptable.log !\n";
   exit $ERRORS{"UNKNOWN"};
}
print FILE "$update_time:$VolIntOut:$VolIntIn:$VolM2Out:$VolM2In:$VolKAKOut:$VolKAKIn:$VolSUSOut:$VolSUSIn";
close(FILE);
if ($flg_created == 0){
   print "First execution : Buffer in creation.... \n";
   exit($ERRORS{"UNKNOWN"});
}
my @Tindic;
my @Tindicb;
my @Unite;
my @liste=("VolIntIn","VolM2In","VolKAKIn","VolSUSIn","VolIntOut","VolM2Out","VolKAKOut","VolSUSOut");
my $i=0;
$diff = time() - $last_time;
if ($diff == 0){$diff = 1;}
my $message="TRAFIC ESSL MOREA :";
my $perfparse="|";
for($i=0; $i<8; $i++) {
   #print "Indicateur $liste[$i] : $Resultat[$i]\n";
   if (($Resultat[$i] - $last_Resultat[$i] != 0) && defined($last_Resultat[$i])) {
	$Tindic[$i] = 0;
	if ($Resultat[$i] - $last_Resultat[$i] < 0){
	   $total = $Resultat[$i];
	} else {
	   $total = $Resultat[$i] - $last_Resultat[$i];
	}
	#if ($debug_val != 0) {print "total=$total diff=$diff\n";}
	#my $pct_out_traffic = $Tindic1 = abs($total / $diff);
	$Tindic[$i] = abs($total / $diff)*8;   #en bits/s
	$Tindic[$i] = int($Tindic[$i]);
   } else {
       $Tindic[$i] = 0;
   }
   $Unite[$i]="bits/s";
   $Tindicb[$i]=$Tindic[$i];
   if($Tindic[$i]>1000) {
	   $Unite[$i]="kbits/s";
   	   $Tindic[$i]=$Tindic[$i]/1000;
   }
   $message = $message." $perf[$i] : $Tindic[$i] $Unite[$i] ";
   $perfparse = $perfparse." ".$perf[$i]."=".$Tindicb[$i];
}


#print "Resultat:$stat0,$stat1,$stat2,$stat3,$stat4,$stat5,$stat6 \n";
print "$message$perfparse\n";
exit 0;
