#!/bin/sh

#####################################################################
## Script d'accounting PSIN
#####################################################################

#########################################
##
## variables globales
##
PROXY_PORTS="80,8080,443,3128"
LDAP_PORTS="389,636"
POP3_PORTS="110,995"
IMAP_PORTS="143,993"
SMTP_PORTS="25,465"
KAK_INFO="15000"
KAK_ADMIN="13000"
#########################################

%if %%nombre_interfaces >= "2"
## proxies nationaux
ipset -X  proxies 2>/dev/null
# serveurs Melanie2
ipset -X  melanie2 2>/dev/null
# serveurs KAK
ipset -X  kak 2>/dev/null
# serveurs DNS
ipset -X  dns 2>/dev/null
# serveurs wsus
ipset -X  wsus 2>/dev/null
# serveurs ldap
ipset -X ldap 2>/dev/null
# serveurs DNS
ipset -X portdns 2>/dev/null
# portnetbios
ipset -X portnetbios 2>/dev/null

# proxies nationaux
ipset -N proxies iphash --hashsize 32 --probes 1
%for %%proxy_iter in %%serveurs_proxies_nationaux_ip
ipset -A proxies %%proxy_iter
%end for

# serveurs melanie2
ipset -N melanie2  iphash --hashsize 32 --probes 1
%for %%melanie2_iter in %%serveurs_melanie2_nationaux_ip
ipset -A melanie2 %%melanie2_iter
%end for

## serveurs KAK
ipset -N kak iphash --hashsize 32 --probes 1
%for %%kak_iter in %%serveurs_kak_nationaux_ip
ipset -A kak %%kak_iter
%end for

# serveurs dns
ipset -N dns iphash --hashsize 8 --probes 1
%for %%dns_iter in %%serveurs_dns_nationaux_ip
ipset -A dns %%dns_iter
%end for

# serveurs wsus national
ipset -N wsus iphash --probes 8
%for %%wsus_iter in %%serveurs_wsus_nationaux_ip
ipset -A wsus %%wsus_iter
%end for

ipset -N portdns portmap --from 1 --to 1024
ipset -A portdns 53
#
ipset -N portnetbios portmap --from 135 --to 445
ipset -A portnetbios 135
ipset -A portnetbios 137
ipset -A portnetbios 138
ipset -A portnetbios 139
ipset -A portnetbios 445
#



# Declaration des chaines
# ** Protocoles a destination des proxies nationaux **
/sbin/iptables -N int-proto
/sbin/iptables -t filter -I int-proto -i eth1 -p tcp -m multiport --sport $PROXY_PORTS -m comment --comment "ACC-flux_in-proxies-http"
/sbin/iptables -t filter -I int-proto -o eth1 -p tcp -m multiport --dport $PROXY_PORTS -m comment --comment "ACC-flux_out-proxies-http"
# ** Protocoles Melanie2 **
/sbin/iptables -N mel-proto
/sbin/iptables -t filter -I mel-proto -i eth1 -p tcp -m multiport --sport $POP3_PORTS -m comment --comment "ACC-flux_in-melanie2-pop"
/sbin/iptables -t filter -I mel-proto -i eth1 -p tcp -m multiport --sport $SMTP_PORTS  -m comment --comment "ACC-flux_in-melanie2-smtp"
/sbin/iptables -t filter -I mel-proto -i eth1 -p tcp -m multiport --sport $IMAP_PORTS -m comment --comment "ACC-flux_in-melanie2-imap"
/sbin/iptables -t filter -I mel-proto -i eth1 -p tcp -m multiport  --sport $LDAP_PORTS -m comment --comment "ACC-flux_in-melanie2-ldap(s)"
/sbin/iptables -t filter -I mel-proto -o eth1 -p tcp -m multiport --dport $POP3_PORTS -m comment --comment "ACC-flux_out-melanie2-pop"
/sbin/iptables -t filter -I mel-proto -o eth1 -p tcp -m multiport --dport $SMTP_PORTS  -m comment --comment "ACC-flux_out-melanie2-smtp"
/sbin/iptables -t filter -I mel-proto -o eth1 -p tcp -m multiport --dport $IMAP_PORTS -m comment --comment "ACC-flux_out-melanie2-imap"
/sbin/iptables -t filter -I mel-proto -o eth1 -p tcp -m multiport  --dport $LDAP_PORTS -m comment --comment "ACC-flux_out-melanie2-ldap(s)"
# ** Protocoles  KAK **
/sbin/iptables -N kak-proto
/sbin/iptables -t filter -I kak-proto -i eth1 -p tcp -m multiport --sport $KAK_INFO -m comment --comment "ACC-flux_in-kak-port15000"
/sbin/iptables -t filter -I kak-proto -i eth1 -p tcp -m multiport --sport $KAK_ADMIN -m comment --comment "ACC-flux_in-kak-port13000"
/sbin/iptables -t filter -I kak-proto -o eth1 -p tcp -m multiport --dport $KAK_INFO -m comment --comment "ACC-flux_out-kak-port15000"
/sbin/iptables -t filter -I kak-proto -o eth1 -p tcp -m multiport --dport $KAK_ADMIN -m comment --comment "ACC-flux_out-kak-port13000"
#Declaration des chaines
%end if

%if %%nombre_interfaces >= "3"
# Flux de la zone LAN vers Morea
# Flux globaux LAN <-----> MOREA
/sbin/iptables -I lan-mor -i eth2 -o eth1 -m comment --comment "ACC-flux_in-lan-morea"
/sbin/iptables -I mor-lan -i eth1 -o eth2 -m comment --comment "ACC-flux_out-lan-morea"
#
# Flux Morea PC sur LAN en direct sur  serveurs proxies nationaux
/sbin/iptables -I lan-mor  -i eth2 -o eth1 -m set --set  proxies dst -m comment --comment "ACC-flux_out-lan-proxies" -j int-proto
/sbin/iptables -I mor-lan  -i eth1 -o eth2  -m set --set  proxies src -m comment --comment "ACC-flux_in-lan-proxies" -j int-proto
#
# Flux
# Flux Morea serveurs messagerie nationaux LAN <---> serveurs Nationaux melanie2
/sbin/iptables -I lan-mor -i eth2 -o eth1 -m set --set  melanie2 dst  -m comment --comment "ACC-flux_out-lan-melanie2" -j mel-proto
/sbin/iptables -I mor-lan -i eth1 -o eth2 -m set --set  melanie2 src -m comment --comment "ACC-flux_in-lan-melanie2"  -j mel-proto
#
# Flux Morea serveurs  KAK national
/sbin/iptables -I lan-mor -i eth2 -o eth1 -m set --set  kak dst  -m comment --comment "ACC-flux_out-lan-kak" -j kak-proto
/sbin/iptables -I mor-lan -i eth1 -o eth2 -m set --set  kak src  -m comment --comment "ACC-flux_in_lan-kak" -j kak-proto
#
# Flux Morea serveurs dns national
/sbin/iptables -I lan-mor -i eth2 -o eth1 -m set --set  portdns dst  -m comment --comment "ACC-flux_out-lan-dns"
/sbin/iptables -I mor-lan -i eth1 -o eth2 -m set --set  portdns src  -m comment --comment "ACC-flux_in-lan-dns"
#
# Flux netbios serveurs nationaux
/sbin/iptables -I lan-mor -i eth2 -o eth1 -m set --set portnetbios src -m comment --comment "ACC-flux_out-lan-netbios"
/sbin/iptables -I mor-lan -i eth1 -o eth2 -m set --set portnetbios dst -m comment --comment "ACC-flux_in-lan-netbios"
#
# Flux wsus serveurs nationaux
/sbin/iptables -I lan-mor -i eth2 -o eth1 -m set --set wsus src -m comment --comment "ACC-flux_out-lan-wsus"
/sbin/iptables -I mor-lan -i eth1 -o eth2 -m set --set wsus dst -m comment --comment "ACC-flux_in-lan-wsus"
#
# Flux Bastion vers Morea
# flux proxies
/sbin/iptables -I mor-bas -i eth2 -o eth1 -p tcp -m multiport --sport $PROXY_PORTS -m comment --comment "ACC-flux_in-proxies-bastion-proxies"
/sbin/iptables -I bas-mor -i eth1 -o eth2 -p tcp -m multiport --dport $PROXY_PORTS -m comment --comment "ACC-flux_out-proxies-bastion-proxies"
%end if



